.. image:: https://api.travis-ci.org/pycontribs/activedirectory.png?branch=master
        :target: https://travis-ci.org/pycontribs/activedirectory

.. image:: https://coveralls.io/repos/pycontribs/activedirectory/badge.png?branch=master
        :target: https://coveralls.io/r/pycontribs/activedirectory

.. image:: https://pypip.in/d/activedirectory/badge.png
        :target: https://pypi.python.org/pypi/activedirectory/

.. image:: https://pypip.in/v/activedirectory/badge.png
        :target: https://pypi.python.org/pypi/activedirectory/

.. image:: https://pypip.in/egg/activedirectory/badge.png
        :target: https://pypi.python.org/pypi/activedirectory/

.. image:: https://pypip.in/wheel/activedirectory/badge.png
        :target: https://pypi.python.org/pypi/activedirectory/

.. image:: https://pypip.in/license/activedirectory/badge.png
        :target: https://pypi.python.org/pypi/activedirectory/

activedirectory
===============

Easiest way to interact with ActiveDirectory / AD / LDAP Servers from Python, pure python approach. 
